Struct
QmiIndicationLocFixRecurrenceTypeOutput
since: 1.22
Description [src]
struct QmiIndicationLocFixRecurrenceTypeOutput {
/* No available fields */
}
The QmiIndicationLocFixRecurrenceTypeOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.22
Instance methods
qmi_indication_loc_fix_recurrence_type_output_get_fix_recurrence_type
Get the ‘Fix Recurrence Type’ field from self.
since: 1.22
qmi_indication_loc_fix_recurrence_type_output_ref
Atomically increments the reference count of self by one.
since: 1.22
qmi_indication_loc_fix_recurrence_type_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.22