Struct
QmiIndicationLocSetNmeaTypesOutput
since: 1.26
Description [src]
struct QmiIndicationLocSetNmeaTypesOutput {
/* No available fields */
}
The QmiIndicationLocSetNmeaTypesOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.26
Instance methods
qmi_indication_loc_set_nmea_types_output_get_indication_status
Get the ‘Indication Status’ field from self.
since: 1.26
qmi_indication_loc_set_nmea_types_output_ref
Atomically increments the reference count of self by one.
since: 1.26
qmi_indication_loc_set_nmea_types_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.26